@@ -33,7 +33,7 @@ def get_run_options():
 
 
 def run_ftsb_redisearch(redis_url, ftsb_redisearch_path, setup_run_json_output_fullpath, options, input_file, workers=1,
-                        pipeline=1, oss_cluster_mode=False, max_rps=0, args=[] ):
+                        pipeline=1, oss_cluster_mode=False, max_rps=0, requests=0, continue_on_error=False, args=[]):
     ##################
     # Setup commands #
     ##################
@@ -44,9 +44,13 @@ def run_ftsb_redisearch(redis_url, ftsb_redisearch_path, setup_run_json_output_f
                   "--pipeline={}".format(pipeline),
                   "--json-out-file={}".format(setup_run_json_output_fullpath)]
     if max_rps > 0:
-        ftsb_args += ["--max-rps", max_rps]
+        ftsb_args += ["--max-rps={}".format(max_rps)]
+    if requests > 0:
+        ftsb_args += ["--requests={}".format(requests)]
     if oss_cluster_mode:
         ftsb_args += ["--cluster-mode"]
+    if continue_on_error:
+        ftsb_args += ["--continue-on-error"]
 
     ftsb_process = subprocess.Popen(args=ftsb_args, **options)
     if ftsb_process.poll() is not None:
